#!/usr/bin/env python

"""
	Generate stats output for video logs.
	
	generate_stats.py [--force-all]
	
	The --force-all option will generate stats for all log files found. If not
	supplied, only logs from the current month are generated.
"""

import os
import re
import sys
import time

datelog_expression = re.compile("^[0-9]{6}_.*")

force_all = False
if "--force-all" in sys.argv:
	force_all = True

os.chdir("/var/www/stp/stats")

# Get a list of log files
logs = []
for name in os.listdir("."):
	if name[-3:] == "log":
		logs.append(name)

# Find the logs to actually update stats for
if not force_all:
	tmp = logs
	logs = []
	now = time.localtime()
	
	for name in tmp:
		# We only care about logs with a date in the name
		if datelog_expression.match(name):
			date = time.strptime(name[:6], "%Y%m")
			if date.tm_year == now.tm_year and date.tm_mon == now.tm_mon:
				logs.append(name)

# Generate stats
for log in logs:
	print >>sys.stderr, "Generating log for %s" % log
	os.system("./SimpleStats.rb %s" % log)

